/**
 * module WYSIWYG (helpers)
 *
 * @author Evgueni V. Palchukovsky <epalchukovsky@swsoft.com>
 * @version $Id: modulewysiwyg_helpers.js,v 1.6 2006/02/21 10:53:35 abelyaev Exp $
 * @since 2006/01/31
 * @package SiteBuilder
 * @subpackage modules API
 * @copyright (c) 2004-2006, SWsoft
 */

function ModuleWysiwygPsevdoAction(id) {
	var f = document.forms[id];
	if (_moduleWysiwyg && f && _moduleWysiwyg.SubmitAll()) {
		f.setAttribute('action', _formsActionsBackup[id]);
		f.submit();
	}
}

function ModuleWysiwygAction() {
	return _moduleWysiwyg && _moduleWysiwyg.SubmitAll();
}

function Pause(numberMillis) {
	var now = new Date();
	var exitTime = now.getTime()+numberMillis;
	while (true) {
		now = new Date();
		if (now.getTime()>exitTime) {
			return;
		}
	}
}

function Trim(str) {
   var buf = str;
   var ch = buf.substring(0, 1);
   while (ch==" ") {
      buf = buf.substring(1, buf.length);
      ch = buf.substring(0, 1);
   }
   ch = buf.substring(buf.length-1, buf.length);
   while (ch==" ") {
      buf = buf.substring(0, buf.length-1);
      ch = buf.substring(buf.length-1, buf.length);
   }
   while (buf.indexOf("  ")!=-1) {
      buf = buf.substring(0, buf.indexOf("  "))+buf.substring(buf.indexOf("  ")+1, buf.length);
   }
   return buf;
}


function StripHtml(html) {
	var buf = html.replace(/(<([^>]+)>)/ig, "");
	buf = buf.replace(/\r\n/g, " ");
	buf = buf.replace(/\n/g, " ");
	buf = buf.replace(/\r/g, " ");
	buf = Trim(buf);
	return buf;
}

function SetLeft(parentControl, targetControl, offset_) {
	offset_ += parentControl.offsetLeft;
	for(	var node = parentControl.offsetParent;
			node && node!=targetControl.offsetParent;
			node = node.offsetParent) {
		offset_ += node.offsetLeft;
	}
	targetControl.style.left = offset_;
	return offset_;
}

function SetTop(parentControl, targetControl, offset_) {
	offset_ += parentControl.offsetTop;
	for(	node = parentControl.offsetParent;
			node && node!=targetControl.offsetParent;
			node = node.offsetParent) {
		offset_ += node.offsetTop;
	}
	targetControl.style.top = offset_;
	return offset_;
}

////////////////
// Classes


function Styler() {

	this.m_ok = false;
	this.m_style = null;

	this.IsOk = function() {
		return this.m_ok;
	}

	this.GetStyle = function() {
		return this.m_style;
	}

	this._ReadRule = function(ruleObj, className_) {
		if (	_moduleWysiwyg.IsIe()
			||	(!_moduleWysiwyg.IsIe() && ruleObj.constructor==CSSStyleRule)) {
			var buff = ruleObj.selectorText.substring(0, 1)=="."
				?	ruleObj.selectorText.substring(1)
				:	ruleObj.selectorText;
			if (className_==buff) {
				this.m_style = ruleObj.style;
				return true;
			} else {
				return false;
			}
		} else if (ruleObj.constructor==CSSImportRule) {
			return this._ReadImportRule(ruleObj, className_);
		}
	}

	this._ReadImportRule = function(ruleObj, className_, tagName_) {
		for (var i = ruleObj.styleSheet.cssRules.length-1; i>=0; --i) {
			if (this._ReadRule(ruleObj.styleSheet.cssRules[i], className_)) {
				return true;
			}
		}
		return false;
	}

	this.ReadStyle = function(ctrl) {
		this.m_ok = ctrl && ctrl.className;
		if (this.m_ok) {
			for (var i = document.styleSheets.length-1; i>=0; --i) {
				var rules = _moduleWysiwyg.IsIe()
					?	document.styleSheets[i].rules
					:	document.styleSheets[i].cssRules;
				for (var j = rules.length-1; j>=0; --j) {
					if (this._ReadRule(rules[j], ctrl.className)) {
						return true;
					}
				}
			}
			this.m_ok = false;
		}
		return this.m_ok;
	}

}

///////////////////////////////////////////////////////////////////////////
// Keyboard events

function ModuleWysiwygKeyPressGecko(event_) {
	var editor = _moduleWysiwyg.GetEditor(event_.target.id);
	if (!editor || !event_.ctrlKey) {
		return;
	}
	var key = String.fromCharCode(event_.charCode).toLowerCase();
	var cmd = false;
	switch (key) {
		case 'b':
			cmd = "bold";
			break;
		case 'i':
			cmd = "italic";
			break;
		case 'u':
			cmd = "underline";
			break;
	};
	if (cmd) {
		editor.ExecCommand(cmd, null);
		event_.preventDefault();
		event_.stopPropagation();
	}
}

function ModuleWysiwygIeButtonRaise(e) {
	var el = window.event.srcElement;
	var cls = el.className;
	if (cls=="rteImage" || cls=="rteImageLowered") {
		el.className = "rteImageRaised";
	}
}

function ModuleWysiwygIeButtonNormal(e) {
	var el = window.event.srcElement;
	var cls = el.className;
	if (cls=="rteImageRaised" || cls=="rteImageLowered") {
		el.className = "rteImage";
	}
}

function ModuleWysiwygIeButtonLower(e) {
	var el = window.event.srcElement;
	var cls = el.className;
	if (cls=="rteImage" || cls=="rteImageRaised") {
		el.className = "rteImageLowered";
	}
}

function PopUpWin(url, win, width, height, options) {
	var leftPos = (screen.availWidth-width)/2;
	var topPos = (screen.availHeight-height)/2;
	options += 'width='+width+',height='+height+',left='+leftPos+',top='+topPos;
	return window.open(url, win, options);
}

function SetImageId(editorId, moduleId) {
	try {
		window.InsertImage.document.insertWysiwygImage.editorId.value = editorId;
		window.InsertImage.document.insertWysiwygImage.moduleId.value = moduleId;
	} catch (e) {
		setTimeout("SetImageId('"+editorId+"', '"+moduleId+"');", 100);
	}
}

var _imgCounter = 0;
function ImageBackup(imgCtrl, imgRealSrc) {
	imgCtrl.id = 'mw_user_img'+(++_imgCounter);
	this.id = imgCtrl.id;
	this.src = imgRealSrc;
}