HTMLArea.prototype.execCommand = function(cmdID, UI, param) {
	this._undoTakeSnapshot();
	var editor = this; 
	this.focusEditor();
	var ani=this.getAllAncestors();

	switch (cmdID.toLowerCase()) {
		case "justifyleft":
		case "justifyright":
		case "justifycenter":
		case "justifyfull":
			this.execCommand_justify(cmdID, UI, param, editor, ani);
			break;
		case "hilitecolor":
			(HTMLArea.is_ie) && (cmdID = "backcolor");
		case "forecolor":
			this.execCommand_forecolor(cmdID, UI, param, editor, ani);
			break;	  
		case "bold":
			this._undoTakeSnapshot();
			this._bold(cmdID, UI, param);
			this._undoTakeSnapshot();
			break;  
		case "italic":
			this._undoTakeSnapshot();
			if (HTMLArea.is_ie) {
				this._italic(cmdID, UI, param);
			} else {
				this.CheckWordSelection();
				this._doc.execCommand(cmdID, UI, param);
			}
			this._undoTakeSnapshot();
			break;
		case "underline":
			this._undoTakeSnapshot();
			if (!HTMLArea.is_ie) {
				this.CheckWordSelection();
			}
			this._doc.execCommand(cmdID, UI, param);
			this._undoTakeSnapshot();
			break;
		case "strikethrough":
			this._undoTakeSnapshot();
			if (!HTMLArea.is_ie) {
				this.CheckWordSelection();
			}
			this._doc.execCommand(cmdID, UI, param);
			break;
			this._undoTakeSnapshot();
		case "fontname":
			this._undoTakeSnapshot();
			this.CheckWordSelection();
			this._fontname(cmdID, UI, param);
			this._undoTakeSnapshot();
			break;
		case "fontsize":
			this._undoTakeSnapshot();
			this.CheckWordSelection();
			this._fontsize(cmdID, UI, param);
			this._undoTakeSnapshot();
			break;
		case "formatblock":
			this.execCommand_formatblock(cmdID, UI, param, editor, ani);
			break;
		case "insertorderedlist":
		case "insertunorderedlist":
			this.execCommand_insertlist(cmdID, UI, param, editor, ani);
			break;
		case "inserthorizontalrule":
			this._undoTakeSnapshot();
			var hr=this._doc.createElement("hr");
			this.insertNodeAtSelection(hr, true);
			this._undoTakeSnapshot();
			break;
		case "createlink": 
			this.fCreateLink();
			break;
		case "undo":
			if (this._customUndo)
				this.undo();
			else
				this._doc.execCommand(cmdID, UI, param);
			break;  
		case "redo":
			if (this._customUndo)
				this.redo();
			else
				this._doc.execCommand(cmdID, UI, param);
			break;
		case "subscript":
			this._undoTakeSnapshot();
			if (!HTMLArea.is_ie) {
				this.CheckWordSelection();
			}
			var cas;
			for (var i in this._toolbarObjects) {
				var btn = this._toolbarObjects[i];
				if (btn.name=="superscript") {
					cas=btn.active;
				}
			}
			if (cas) {
				this._doc.execCommand("superscript", UI, param);
				this._doc.execCommand(cmdID, UI, param);
				break;
			}
			this._doc.execCommand(cmdID, UI, param);
			this._undoTakeSnapshot();
			break;
		case "superscript":
			this.execCommand_superscript(cmdID, UI, param, editor, ani);
			break;
		case "inserttable": 
			this._insertTable(false);
			break;
		case "insertimage": 
			this._insertImage();
			break;
		case "about": 
			this._popupDialog("about.html", null, null);
			break;
		case "showhelp": 
			window.open("reference.html", "ha_help");
			break;
		case "insertform": 
			this.sInsertForm();
			break;
		case "inserttextfield": 
			this.sFormTextField();
			break;
		case "inserttextarea": 
			this.sFormTextArea();
			break;
		case "insertbutton": 
			this.sFormButton();
			break;
		case "insertsubmit": 
			this.sFormSubmit();
			break;
		case "insertcheck": 
			this.sFormCheck();
			break;
		case "insertradio": 
			this.sFormRadio();
			break;
		case "insertdropdown": 
			this.sFormDropdown();
			break;
		case "inserthidden": 
			this.sFormHidden();
			break;
		case "selectall": 
			this.sSelectAll();
			break;
		case "htmlmode": 
			this.setMode("html");
			break;
		case "dsmode": 
			this.setMode("wysiwyg");
			break;
		case "prvmode": 
			this.setMode("preview");
			break;
		case "insertsymbol": 
			this.InsSymbols();
			break;
		case "tagedit": 
			this.TagEdit();
			break;
		case "tagprop": 
			this.TagProperty();
			break;
		case "tagstl": 
			this.TagStl();
			break;
		case "finde": 
			this.fFinde();
			break;
		case "cleansel": 
			this.fCleanSel();
			break;
		case "cleansel1": 
			this.fCleanSel1();
			break;
		case "cleansel2": 
			this.fCleanSel2();
			break;
		case "deltag": 
			this.fDelTag();
			break;
		case "spell": 
			this.fSpell(); 
			break;
		case "fullscreen":
			this.execCommand_fullscreen(cmdID, UI, param, editor, ani);
			break;
		case "shbord":
			this.execCommand_shbord(cmdID, UI, param, editor, ani);
			break;
		case "shscr":
			this.execCommand_shscr(cmdID, UI, param, editor, ani);
			break;
		case "indent":
			this.execCommand_indent(cmdID, UI, param, editor, ani);
			break;
		case "outdent":
			this.execCommand_outdent(cmdID, UI, param, editor, ani);
			break;
		default:
			this._doc.execCommand(cmdID, UI, param);
	}   
	this.updateToolbar();
	this.editableContentResize();
	return false;
};

HTMLArea.prototype.execCommand_justify = function(cmdID, UI, param, editor, ani) {
	var align;
	
	switch (cmdID.toLowerCase()) {
		case "justifyleft":
			align="left";
			break;
		case "justifyright":
			align="right";
			break;
		case "justifycenter":
			align="center";
			break;
		case "justifyfull":
			align="justify";
			break;
	}
	
	this._undoTakeSnapshot();
	this.fAlign(align);
	this.retSelection();
	this._undoTakeSnapshot();
}


HTMLArea.prototype.execCommand_formatblock = function(cmdID, UI, param, editor, ani) {
	this._undoTakeSnapshot();
	if (param=="none") {
	} else {
		var tagName = ani[0].tagName.toLowerCase();
		var testTD=false;
		var sel = editor._getSelection();
		var range = editor._createRange(sel);
		if (tagName =='hr') {
			alert(fMessage("notallowedoperation"));
			return;
		}
		if (HTMLArea.is_ie) {
			if (/<td>/i.test(range.htmlText)) {
				testTD = true;
			}
		} else {
			var text = this.getSelectedHTML();
			if (/<td>/i.test(text)) {
				testTD = true;
			}
		}
		if (HTMLArea.is_ie) {
			if (tagName =="img" || tagName == "li" || tagName == "ol" || tagName =="ul" || testTD) {
				if (tagName =="img") {
					this.selectNodeContents(ani[1]);
				}
				this._doc.execCommand(cmdID, UI, param);
				return;
			}
			var ss=ani[0].innerHTML;
			while(/ /.test(ss)) {
				ss=ss.replace(" ","");
			}
			ss=ss.toLowerCase();
			var ok=false;
			if (tagName !="p" && tagName !="adress" && tagName !="pre" && tagName !="h1" && 
				tagName !="h2" && tagName !="h3" && tagName !="h4" && tagName !="h5" && 
				tagName !="h6") {
					ok=true;
			}
			try{
				if (ani[0].childNodes.length==1 && 
					ss.substr(0,5)=="<font" && 
					ss.substr(ss.length-5,5)=="font>") {
						ok=true;
					}
			}catch(e) {
			}
			var an=this.getAllAncestors();
			if (!ok && tagName != "body") {
				var str=ani[0].innerHTML;
				var tag=param.replace("<", "");
				tag=tag.replace(">", "");
				var pre=this._doc.createElement(tag);
				ani[0].replaceNode(pre);
				pre.innerHTML=str;
				this.selectNodeContents(pre);
			} else {
				var mass = this.getTagInSelection();
				mass = this.verTapName(mass);
				for(var i=0;i<mass.length;i++) {
					var tag=param.replace("<", "");
					tag=tag.replace(">", "");
					var pre=this._doc.createElement(tag);
					try{
						var eee = mass[i].firstChild.innerHTML;
					}catch(e) {
						var eee = "undefined";
					}
					if (mass[i].tagName.toLowerCase()=="ol" || 
						mass[i].tagName.toLowerCase()=="ul") {
						var cn = mass[i].getElementsByTagName("li");
						for(var i1=0; i1<cn.length;i1++) {
							try{
								var tag1 = cn[i1].tagName.toLowerCase();
							}catch(e) {
								var tag1 = "undefined";
							}
							if (tag1=="li") {
								pre=this._doc.createElement(tag);
								try{
									var eee1 = cn[i1].firstChild.tagName.toLowerCase();
								}catch(e) {
									var eee1 = "undefined";
								}
								if (eee1=="p" || eee1=="address" || eee1=="pre" || eee1=="h1" || 
									eee1=="h2" || eee1=="h3" || eee1=="h4" ||
									eee1=="h5"||eee1=="h6") {
									pre.innerHTML = cn[i1].firstChild.innerHTML;
									cn[i1].innerHTML="";
									cn[i1].appendChild(pre);
								} else {
									pre.innerHTML = cn[i1].innerHTML;
									cn[i1].innerHTML="";
									cn[i1].appendChild(pre);
								}
							} else {
								cn[i1].parentNode.removeChild(cn[i1]);
							}
						}
					} else {
						if (eee=="undefined" || typeof eee=="undefined") {
							pre.innerHTML = mass[i].innerHTML;
						} else {
							pre.innerHTML = mass[i].firstChild.innerHTML;
						}
						if (mass[i].tagName.toLowerCase()=="td") {
							mass[i].innerHTML="";
							mass[i].appendChild(pre);
						} else {
							mass[i].parentNode.replaceChild(pre,mass[i]);
						}
					}
					this.selectNodeContents(pre);
				}
			}
		} else {
			if (tagName =="ol" ||  tagName =="ul") {
				var li = ani[0].getElementsByTagName("li");
				for(var i = 0; i<li.length; i++) {
					this.selectNodeContents(li[i]);
					this._doc.execCommand(cmdID, UI, param);
				}
				this.selectNodeContents(ani[0]);
				return;
			} else if (this.key=="13" || this.key=="40" || this.key=="38" || this.key=="8" || 
						this.key=="39" || this.key=="37" || this.key=="46" || tagName == "li" || 
						tagName == "img" || testTD) {
				this._doc.execCommand(cmdID, UI, param);
				return;
			}
			try{
				var stl=ani[0].style;
				ani[0].removeAttribute("style");
			}catch(e) {
			}
			var ss=ani[0].innerHTML;
			while(/ /.test(ss)) {
				ss=ss.replace(" ","");
			}
			ss=ss.toLowerCase();
			var ok=false;
			if (tagName !="p" && tagName !="adress" && tagName !="pre" && tagName !="h1" && 
				tagName !="h2" && tagName !="h3" && tagName !="h4" && tagName !="h5" && 
				tagName !="h6") {
					ok=true;
				}
			try{
				if (ani[0].childNodes.length==1 && ss.substr(0,5)=="<font" && ss.substr(ss.length-5,5)=="font>") {
					ok=true;
				}
			}catch(e) {
			}
			var an=this.getAllAncestors();
			if (!ok && tagName !="body") {
				var mass = this.getTagInSelection();
				var massTagName = mass[0].tagName.toLowerCase();
				if (mass.length==1 &&
					(massTagName =="p" || massTagName == "h1" || massTagName == "h2" ||massTagName == "h3" ||
						massTagName == "h4" || massTagName == "h5" || massTagName == "h6" ||
						massTagName == "pre"|| massTagName =="address")) {
				//	this.selectNodeContents(an[0]);
				}
				this._doc.execCommand(cmdID, UI, param);
			} else {
				var mass = this.getTagInSelection();
				mass = this.verTapName(mass);
				for(var i=0;i<mass.length;i++) {
					var tag=param.replace("<", "");
					var massTagName = mass[i].tagName.toLowerCase();
					tag=tag.replace(">", "");
					var pre=this._doc.createElement(tag);
					try{
						var eee = mass[i].firstChild.innerHTML;
					}catch(e) {
						var eee = "undefined";
					}
					if (massTagName == "ol" || massTagName == "ul") {
						var cn = mass[i].getElementsByTagName("li");
						for(var i1=0; i1<cn.length;i1++) {
							try{
								var tag1 = cn[i1].tagName.toLowerCase();
							}catch(e) {
								var tag1 = "undefined";
							}
							if (tag1=="li") {
								pre=this._doc.createElement(tag);
								try{
									var eee1 = cn[i1].firstChild.tagName.toLowerCase();
								}catch(e) {
									var eee1 = "undefined";
								}
								if (eee1=="p"||eee1=="address"||eee1=="pre"||eee1=="h1"||eee1=="h2"||eee1=="h3"||eee1=="h4"||eee1=="h5"||eee1=="h6") {
									pre.innerHTML = cn[i1].firstChild.innerHTML;
									cn[i1].innerHTML="";
									cn[i1].appendChild(pre);
								} else {
									pre.innerHTML = cn[i1].innerHTML;
									cn[i1].innerHTML="";
									cn[i1].appendChild(pre);
								}
							} else {
								cn[i1].parentNode.removeChild(cn[i1]);
							}
						}
					} else {
						if (eee=="undefined" || typeof eee=="undefined") {
							pre.innerHTML = mass[i].innerHTML;
						} else {
							pre.innerHTML = mass[i].firstChild.innerHTML;
						}
						if (massTagName == "td") {
							mass[i].innerHTML="";
							mass[i].appendChild(pre);
						} else {
							mass[i].parentNode.replaceChild(pre,mass[i]);
						}
					}
					this.selectNodeContents(pre);
				}
			}
			try{
				ani[0].style=stl;
			}catch(e) {
			}
		}
	}
	if (ani[0].tagName.toLowerCase()=='body') {
		this.selectNodeContents(ani[0]);
	}
	this._undoTakeSnapshot();
	this.updateToolbar();
}


HTMLArea.prototype.execCommand_forecolor = function(cmdID, UI, param, editor, ani) {
	this._undoTakeSnapshot();
	var obj = new Object();
	obj.color =  HTMLArea._colorToRgb(this._doc.queryCommandValue(cmdID));
	obj.sp2 = sp2Detect(__trastedSite);
	obj.str = fMessage("default");
	obj.lang=Lang;
	var an=this.getAllAncestors();
	var ou=an[0];
	var span;
	var childs = ou.childNodes;
	var rr;
	span=this._doc.createElement("span");
	var select_text=this.getSelectedHTML();
	var fragment = this._doc.createDocumentFragment();
	var new_select_text;
	this._popupDialog("select_color.html", function(color) {
		if (color) {
			if (color=="default") {
				var el = editor.getParentElement();
				if (cmdID=="hilitecolor" || cmdID=="backcolor") {
					el.style.backgroundColor="";
				}else if (cmdID=="forecolor") {
					el.style.color="";
					el.color="";
				}
				if (el.tagName.toLowerCase()=="font") {
					if (el.style.cssText=="" && el.color=="") {
						editor.selectNodeContents(el);
						if (HTMLArea.is_ie) {
							editor.insertHTML(el.innerHTML);
						} else {
							var html = el.innerHTML;
							el.parentNode.removeChild(el);
							editor.insertHTML(html);
						}
					}
				}
				if (el.tagName.toLowerCase()=="span") {
					if (el.style.cssText=="") {
						editor.selectNodeContents(el);
						if (HTMLArea.is_ie) {
							editor.insertHTML(el.innerHTML);
						} else {
							var html = el.innerHTML;
							el.parentNode.removeChild(el);
							editor.insertHTML(html);
						}
					}
				}
			} else {
				editor.CheckWordSelection();
				var sttr = editor.getSelectedHTML();
				var rtrt = true;
				if (sttr=="") {
					if (HTMLArea.is_ie) {
						editor._doc.execCommand(cmdID, false, "#" + color);
						rtrt = false;
					} else {
						var tag = editor._doc.createElement("span");
						if (cmdID == "hilitecolor") {
							tag.style.backgroundColor = "#" + color;
						} else {
							tag.style.color = "#" + color;
						}
						editor.insertNodeAtSelection(tag, true);
						editor.selectNodeContents(tag);
					}
				} else {
					if (HTMLArea.is_ie) {
						editor._doc.execCommand(cmdID, false, "#" + color);
					} else {
						var el = editor.getParentElement();
						var sel = editor._getSelection();
						var range = editor._createRange(sel);
						if ((HTMLArea.getHTML(el, false) != HTMLArea.getHTML(range.cloneContents(), false)) || 
							el.tagName.toLowerCase()=="font" || 
							el.tagName.toLowerCase()=="span") {
							if (ou.tagName.toLowerCase()=="font" || ou.tagName.toLowerCase()=="span") {
								if (cmdID == "hilitecolor") {
									ou.style.backgroundColor = "#" + color;
								} else {
									ou.style.color = "#" + color;
								}
							} else {
								editor._doc.execCommand(cmdID, false, "#" + color);
							}
							try{
								if (an[0]=="[object HTMLTableCellElement]") {
									var sp = an[0].getElementsByTagName("span");
									editor.selectNodeContents(sp[0]);
								}
							}catch(e) {
							}
						} else {
							editor._doc.execCommand(cmdID, false, "#" + color);
							if (ou.tagName.toLowerCase()=="ol" || ou.tagName.toLowerCase()=="ul") {
								for(i=0; i<childs.length; i++) {
									new_select_text = childs.item(i).innerHTML;
									childs.item(i).innerHTML="<span style='color:"+color+"'>"+new_select_text+"</span>";
								}
							} else {
								var an=editor.getAllAncestors();
								if (an[0]=="[object HTMLBodyElement]") {
									var cn = editor._doc.body.childNodes;
									for(var i = 0; i<cn.length; i++) {
										if (cn[i]=="[object HTMLParagraphElement]" || 
											cn[i]=="[object HTMLHeadingElement]" || 
											cn[i]=="[object HTMLAddressElement]" || 
											cn[i]=="[object HTMLPreElement]") {
											var cnc=cn[i].childNodes;
											try{
												var txtch = cn[i].firstChild.tagName.toLowerCase();
											}catch(e) {
												var txtch = "none";
											}
											if (txtch!="span") {
												var color_cn=cn[i].style.color;
												var bg_cn=cn[i].style.backgroundColor;
												var span = editor._doc.createElement("span");
												span.style.color = color_cn;
												span.style.backgroundColor = bg_cn;
												span.innerHTML = cn[i].innerHTML;
												cn[i].innerHTML = "";
												cn[i].appendChild(span);
											}else if (cnc.length==1&&txtch=="span") {
											
											}
										}
									}
									editor.selectNodeContents(an[0]);
								} else {
									if (cmdID=="hilitecolor" || cmdID=="backcolor") {
										ou.style.backgroundColor="";
										var rr=ou.innerHTML;
										ou.innerHTML="";
										ou.innerHTML="<span style='background-color:"+color+"'>"+rr+"</span>";
									}else if (cmdID=="forecolor") {
										ou.style.color="";
										ou.color="";
										var rr=ou.innerHTML;
										ou.innerHTML="";
										ou.innerHTML="<span style='color:"+color+"'>"+rr+"</span>";
									}
									editor.selectNodeContents(ou.firstChild);
								}
							}
						}
					}
				}
			}
			var an2=editor.getAllAncestors();
			if (rtrt) {
			editor.selectNodeContents(an2[0]);
		}
		editor.updateToolbar();
		editor._undoTakeSnapshot();
		}
	},obj);
}

HTMLArea.prototype.execCommand_superscript = function(cmdID, UI, param, editor, ani) {
	this._undoTakeSnapshot();
	if (!HTMLArea.is_ie) {
		this.CheckWordSelection();
	}
	var cas;
	for (var i in this._toolbarObjects) {
		var btn = this._toolbarObjects[i];
		if (btn.name=="subscript") {
			cas=btn.active;
		}
	}
	if (cas) {
		this._doc.execCommand("subscript", UI, param);
		this._doc.execCommand(cmdID, UI, param);
		return;
	}
	this._doc.execCommand(cmdID, UI, param);
	this._undoTakeSnapshot();
}


HTMLArea.prototype.execCommand_insertlist = function(cmdID, UI, param, editor, ani) {
	if (cmdID.toLowerCase() == "insertorderedlist") {
		var listType = "OL";
		var listTypeOther = "UL";
	} else {
		var listType = "UL";
		var listTypeOther = "OL";
	}
						
	this.add = true;
	var an1=this.getAllAncestors();		
		
	if (an1[0].tagName.toLowerCase()=="hr") {
		alert(fMessage("notallowedoperation"));
		return;
	}
				
	var tagType="none";
	if (an1[0].tagName.toLowerCase()=='img') {
		try {
			tagType=an1[0].type;
			if (an1[0].tagName.toLowerCase()=="img" && typeof tagType == "undefined") {
				var txtTag=HTMLArea.getHTML(an1[0], true);
				if (/type=\"modules\"/.test(txtTag)) {
					tagType = "modules";
				}
			}
		} catch(e) {	
		}
	}
	
	if (tagType=="modules") {
		alert(fMessage("notallowedoperation"));
		return;
	}
	
	this._undoTakeSnapshot();
	if (HTMLArea.is_ie) {
		var an=this.getAllAncestors();
		var ou=null;
		for(var i=0;i<an.length;i++) {
			if (an[i].tagName.toLowerCase()=="ol" || an[i].tagName.toLowerCase()=="ul") {
				ou=an[i];
				break;
			}
		}
		var blq=false;
		for(var i=0;i<an.length;i++) {
			try{
				var ml= parseInt(an[i].style.marginLeft);
				if (ml>0) {
					if (ml>39 && (ml/40==parseInt(ml/40))) {
						 blq=true;
						break;
					}
				}
			}catch(e) {
			}
		}
		if (blq) {
			if (ou==null) {
				var ttag=this.getParentElement();
				var ttag1=ttag;
				var ol;
				var li;
				ol=this._doc.createElement(listType);
				li=this._doc.createElement("LI");
				ttag.replaceNode(ol);
				ol.appendChild(li);
				if (ttag1.tagName.toLowerCase()=="table" || ttag1.tagName.toLowerCase()=="img") {
					var rr = ttag1.outerHTML;
				} else {
					var rr=ttag1.innerHTML;
				}
				while(rr.match(/<p(.*?)>/i) != null) {
					rr=rr.replace(/<p(.*?)>/i,'');
				}
				while(rr.match(/<\/p>/i) != null) {
					rr=rr.replace(/<\/p>/i,'');
				}
				if (ttag1.tagName.toLowerCase()=="table" || ttag1.tagName.toLowerCase()=="img") {
					li.appendChild(ttag1);
				} else {
					li.innerHTML=rr;
				}
				this.selectNodeContents(ol);
			} else {
				if (ou.tagName.toLowerCase()==listTypeOther.toLowerCase()) {
					var ttt=this._doc.createElement(listType);
					var rr=ou.innerHTML;
					ttt.innerHTML=rr;
					ou.replaceNode(ttt);
					this.selectNodeContents(ttt);
				}
				if (ou.tagName.toLowerCase()==listType.toLowerCase()) {
					var ttt=this._doc.createElement("p");
					var rr=ou.innerHTML;
					while(rr.match(/<li>/i) != null) {
						rr=rr.replace(/<li>/i,'');
					}
					while(rr.match(/<\/li>/i) != null) {
						rr=rr.replace(/<\/li>/i,'');
					}
					while(rr.match(/<p(.*?)>/i) != null) {
						rr=rr.replace(/<p(.*?)>/i,'');
					}
					while(rr.match(/<\/p>/i) != null) {
						rr=rr.replace(/<\/p>/i,'');
					}
					ttt.innerHTML=rr;
					ou.replaceNode(ttt);
					this.selectNodeContents(ttt);
				}
			}
		} else {
			try{
				if (cmdID.toLowerCase()=="insertorderedlist") {
					ou.type="1";
				} else {
					ou.type="disc";
				}
			}catch(e) {
			}
			if (an[0].tagName.toLowerCase()=="img") this.selectNodeContents1(an[0]);
			if (an[0].tagName.toLowerCase()=="table") this.selectNodeContents1(an[1]);
			this._doc.execCommand(cmdID, UI, param);
		}
	} else {
		this.listT=true;
		var els1=this.getAllAncestors();
		var im = els1[0];
		if (els1[0]=="[object HTMLTableElement]" && els1[1].tagName.toLowerCase()=="li") {
			//this.selectNodeContents(els1[2]);
		} 
		this.checkLists(listType,cmdID.toLowerCase(), UI, param);
		//this._doc.execCommand(cmdID, UI, param);
		var els=this.getAllAncestors();
		var im1 = els[0];
		if (els1[0].tagName.toLowerCase()=="body"&&(els[0].tagName.toLowerCase()=="ol"||els[0].tagName.toLowerCase()=="ul")) {
			this.selectNodeContents(els[0]);
		}
		if (im.tagName.toLowerCase()=="img" && im1.tagName.toLowerCase()=="body") {
			this.selectNodeContents(im.parentNode.parentNode);
		}
		if (els[0]=="[object HTMLTableElement]") {
			this.selectNodeContents(els[0]);
		} else {
			try{
				if ((els[2].tagName.toLowerCase()=="ul" || 
					els[2].tagName.toLowerCase()=="ol") && 
					els[0].tagName.toLowerCase()=="img") {
					
					this.selectNodeContents(els[2]);
				}
			}catch(e) {
			}
		}
	}
	this._undoTakeSnapshot();
	this.updateToolbar();
}

HTMLArea.prototype.execCommand_fullscreen = function(cmdID, UI, param, editor, ani) {
	this.fFullscreen();
	if (editor.fullscreen==true) {
		HTMLArea._addClass(elf, "buttonPressed");
		elf.title = editor.mvNST;
	} else {
		HTMLArea._removeClass(elf, "buttonPressed");
		elf.title = editor.mvFST;
	}
}

HTMLArea.prototype.execCommand_shbord = function(cmdID, UI, param, editor, ani) {
	this.fShowBorders();
	if (editor.showborders==true) {
		HTMLArea._addClass(elb, "buttonPressed");
	} else {
		HTMLArea._removeClass(elb, "buttonPressed");
	}
}

HTMLArea.prototype.execCommand_shscr = function(cmdID, UI, param, editor, ani) {
	this.fShowScripts();
	if (editor.showscripts==true) {
		HTMLArea._addClass(els, "buttonPressed");
	} else {
		HTMLArea._removeClass(els, "buttonPressed");
	}
}

HTMLArea.prototype.execCommand_indent = function(cmdID, UI, param, editor, ani) {
	this._undoTakeSnapshot();
	var mass = this.getTagInSelection();
	mass = this.verTapName(mass);
	for(var i=0;i<mass.length;i++) {
		var ml = parseInt(mass[i].style.marginLeft);
		if (isNaN(ml)) {
			ml=0;
		}
		var pl = parseInt(mass[i].style.paddingLeft);
		if (isNaN(pl)) {
			pl=0;
		}
		if (mass[i].tagName.toLowerCase()=="td") {
			mass[i].style.paddingLeft=pl+40+"px";
		} else if (mass[i].tagName.toLowerCase()=="tr" || 
					mass[i].tagName.toLowerCase()=="tbody" || 
					mass[i].tagName.toLowerCase()=="table") {
			p = mass[i];
			while((p.tagName.toLowerCase() != 'table') && (p.tagName.toLowerCase() != 'body')) {
				if (HTMLArea.is_ie) {
					p=p.parentElement;
				} else {
					p = p.parentNode;
					while (p.nodeType == 3) {
						p = p.parentNode;
					}
				}
			}
			if (p.tagName.toLowerCase() == 'table') {
				if (p.parentNode.tagName.toLowerCase()!="body") {
					var ml = parseInt(p.parentNode.style.marginLeft);
					if (isNaN(ml)) {
						ml=0;
					}
					p.parentNode.style.marginLeft=ml+40+"px";
				} else {
					var ml = parseInt(p.style.marginLeft);
					if (isNaN(ml)) {
						ml=0;
					}
					p.style.marginLeft=ml+40+"px";
				}
			}
		} else {
			if (HTMLArea.is_ie) {
				if ((mass[i].tagName.toLowerCase()=="ol"||mass[i].tagName.toLowerCase()=="ul") && ml<40) {
					mass[i].style.marginLeft=ml+80+"px";
				} else {
					mass[i].style.marginLeft=ml+40+"px";
				}
			} else {
				mass[i].style.marginLeft=ml+40+"px";
			}
		}
	}
	
	this._undoTakeSnapshot();
}

HTMLArea.prototype.execCommand_outdent = function(cmdID, UI, param, editor, ani) {
	this._undoTakeSnapshot();
	var mass = this.getTagInSelection();
	for(var i=0;i<mass.length;i++) {
		var ml = parseInt(mass[i].style.marginLeft);
		if (isNaN(ml)) {
			ml=0;
		}
		var pl = parseInt(mass[i].style.paddingLeft);
		if (isNaN(pl)) {
			pl=0;
		}
		if (ml>39) {
			if (HTMLArea.is_ie) {
				if ((mass[i].tagName.toLowerCase()=="ol"||mass[i].tagName.toLowerCase()=="ul")&&ml==80) {
					mass[i].style.marginLeft=ml-80+"px";
					if ((ml-80)==0) {
						mass[i].style.marginLeft = "";
					}
				} else {
					mass[i].style.marginLeft=ml-40+"px";
					if ((ml-40)==0) {
						mass[i].style.marginLeft = "";
					}
				}
			} else {
				mass[i].style.marginLeft=ml-40+"px";
				if ((ml-40)==0) {
					mass[i].style.marginLeft = "";
				}
			}
		}else if (pl>39) {
			mass[i].style.paddingLeft=pl-40+"px";
			if ((pl-40)==0) {
				mass[i].style.paddingLeft = "";
			}
		} else {
			try{
				var tag=mass[i];
				ml = parseInt(mass[i].style.marginLeft);
				if (isNaN(ml)) {
					ml=0;
				}
				pl = parseInt(mass[i].style.paddingLeft);
				if (isNaN(pl)) pl=0;
				while(tag.tagName.toLowerCase()!="body") {
					if (ml>39) {
						tag.style.marginLeft=ml-40+"px";
						break;
					}else if (pl>39) {
						tag.style.paddingLeft=pl-40+"px";
						break;
					}
					if (HTMLArea.is_ie) {
						tag=tag.parentElement;
					} else {
						tag = tag.parentNode;
						while (tag.nodeType == 3) {
							tag = tag.parentNode;
						}
					}
					ml = parseInt(tag.style.marginLeft);
					if (isNaN(ml)) ml=0;
					pl = parseInt(tag.style.paddingLeft);
					if (isNaN(pl)) pl=0;
				}
			}catch(e) {
			}
		}
	}	
	this._undoTakeSnapshot();
}
