#!/bin/sh

if [ -f backup_cfg.txt ]; then
	. ./backup_cfg.txt
fi

if [ -n $1 ]; then

	while [ "x$1" != "x" ]; do
	param=`echo $1 | awk 'BEGIN {FS="="} {print $1}'`
	value=`echo $1 | awk 'BEGIN {FS="="} {print $2}'`
	if [ $param = "--path" ]; then
	BACKUP_PATH=$value
	fi
	if [ $param = "--user" ]; then
	DB_USER=$value
	fi
	if [ $param = "--password" ]; then
	DB_PASSWD=$value
	fi
	if [ $param = "--db" ]; then
	SB_DB_NAME=$value
	fi
	if [ $param = "--workdir" ]; then
	SOURCE_DIR=$value
	fi
	if [ $param = "--file" ]; then
	FILE=$value
	fi
	if [ $param = "--mysqlpath" ]; then
	PATH_TO_MYSQL=$value
	fi
	if [ $param = "--web" ]; then
	RESTORE_FROM_WEB=$value
	fi
	if [ $param = "--config" ]; then
	PATH_TO_CONFIG=$value
	fi
	shift
	done
fi

if [ "x${PATH_TO_CONFIG}" != "x" -a -e "${PATH_TO_CONFIG}" ]; then
	. ${PATH_TO_CONFIG}
fi

if [ "x$RESTORE_FROM_WEB" = "xtrue" -a -f "${BACKUP_PATH}/$FILE" ]; then

	mkdir -p ${BACKUP_PATH}/cache 
	cd ${BACKUP_PATH}/cache
	
	tar -xzvf ${BACKUP_PATH}/$FILE web_${SB_DB_NAME}.sql

	if [ -f web_${SB_DB_NAME}.sql ]; then
		${PATH_TO_MYSQL}mysql --user=${DB_USER} --password=${DB_PASSWD} -e "show databases;" > ${BACKUP_PATH}/cache/restore.tmp
		SBDB_EXIST=`awk '/^${SB_DB_NAME}$/ {print $1}' ${BACKUP_PATH}/cache/restore.tmp`

		if [ "_$SBDB_EXIST" = "_" ]; then
			${PATH_TO_MYSQL}mysql --force --user=${DB_USER} --password=${DB_PASSWD} ${SB_DB_NAME} < web_${SB_DB_NAME}.sql
			echo true
		else
			echo false
		fi
	else
		echo false
	fi
	rm -rf ${BACKUP_PATH}/cache
	exit 0
fi 

if [ -z $BACKUP_PATH ]; then
	echo Enter full path to backup files:
	read BACKUP_PATH
fi

if [ -z $FILE ]; then
	echo Enter name of backup file:
	read FILE
fi

if [ -z $DB_USER ]; then
	echo Enter MySQL login:
	read DB_USER
fi

if [ -z $DB_PASSWD ]; then
	echo Enter MySQL user password:
	read DB_PASSWD
fi

if [ -z $SB_DB_NAME ]; then
	echo Enter database name:
	read SB_DB_NAME
fi

if [ -z $SOURCE_DIR ]; then
	echo Enter full path to Sitebuilder users directory:
	read SOURCE_DIR
fi

#if [ -z $PATH_TO_MYSQL ]; then
#	echo Enter full path to Mysql "bin" directory:
#	read PATH_TO_MYSQL
#fi

old_path=`pwd`
mkdir -p ${BACKUP_PATH}/cache 
cd ${BACKUP_PATH}/cache

if [ -f ${BACKUP_PATH}/$FILE ]; then

	#restore MySQL data
	tar -xzvf ${BACKUP_PATH}/$FILE ${SB_DB_NAME}.sql

	if [ -f ${SB_DB_NAME}.sql ]; then
		${PATH_TO_MYSQL}mysql --user=${DB_USER} --password=${DB_PASSWD} -e "show databases;" > ${BACKUP_PATH}/cache/restore.tmp
		SBDB_EXIST=`awk '/^${SB_DB_NAME}$/ {print $1}' ${BACKUP_PATH}/cache/restore.tmp`

		if [ "X$SBDB_EXIST" != "X" ]; then 
			${PATH_TO_MYSQL}mysqladmin --user=${DB_USER} --password=${DB_PASSWD} create ${SB_DB_NAME}
		fi

		${PATH_TO_MYSQL}mysql --force --user=${DB_USER} --password=${DB_PASSWD} ${SB_DB_NAME} < ${SB_DB_NAME}.sql
	fi

	#restore work folders
	mkdir -p ${SOURCE_DIR}
	cd ${SOURCE_DIR}

	EXCLUDE_SQL=${BACKUP_PATH}/cache/sql_exclude
	echo *.sql > $EXCLUDE_SQL
	echo ./sb_logo/* >> $EXCLUDE_SQL
	echo ./sb_skin/* >> $EXCLUDE_SQL
	echo ./sb_lang/* >> $EXCLUDE_SQL
	echo ./sb_psets/* >> $EXCLUDE_SQL

	tar -X ${EXCLUDE_SQL} -xzvf ${BACKUP_PATH}/$FILE

	#restore SB logo
	LOGO_EXIST=`tar -ztf ${BACKUP_PATH}/$FILE | grep ./sb_logo/`
	if [ "X$LOGO_EXIST" != "X" ]; then
		cd ${BACKUP_PATH}
		if [ -z $IMG_PATH ]; then
			echo Enter full path to Sitebuilder logo:
			read IMG_PATH
		fi
			
		mkdir -p ${IMG_PATH}
		tar -xzvf ${BACKUP_PATH}/$FILE ./sb_logo/*
		cp -p ${BACKUP_PATH}/sb_logo/* ${IMG_PATH}
		rm -rf ${BACKUP_PATH}/sb_logo
	fi

	#restore SB skin
	SKIN_EXIST=`tar -ztf ${BACKUP_PATH}/$FILE | grep ./sb_skin/`
	if [ "X$SKIN_EXIST" != "X" ]; then
		cd ${BACKUP_PATH}
		if [ -z $SKIN_PATH ]; then
			echo Enter full path to Sitebuilder skin:
			read SKIN_PATH
		fi
			
		mkdir -p ${SKIN_PATH}
		tar -xzvf ${BACKUP_PATH}/$FILE ./sb_skin/*
		cp -p -R ${BACKUP_PATH}/sb_skin/* ${SKIN_PATH}
		rm -rf ${BACKUP_PATH}/sb_skin
	fi

	#restore SB lang
	LANG_EXIST=`tar -ztf ${BACKUP_PATH}/$FILE | grep ./sb_lang/`
	if [ "X$LANG_EXIST" != "X" ]; then
		cd ${BACKUP_PATH}
		if [ -z $LANG_PATH ]; then
			echo Enter full path to Sitebuilder languages:
			read LANG_PATH
		fi
			
		mkdir -p ${LANG_PATH}
		tar -xzvf ${BACKUP_PATH}/$FILE ./sb_lang/*
		cp -p -R ${BACKUP_PATH}/sb_lang/* ${LANG_PATH}
		rm -rf ${BACKUP_PATH}/sb_lang
	fi

	# restore SB Page Sets

	# active
	APSETS_EXIST=`tar -ztf ${BACKUP_PATH}/$FILE | grep ./sb_psets/active/`
	if [ "X$APSETS_EXIST" != "X" ]; then
		cd ${BACKUP_PATH}
		if [ -z $APSETS_PATH ]; then
			echo Enter full path to active Sitebuilder Page Sets:
			read APSETS_PATH
		fi
		if [ -z $DPSETS_PATH ]; then
			echo Enter full path to non-active Sitebuilder Page Sets:
			read DPSETS_PATH
		fi

			
		mkdir -p ${APSETS_PATH}
		tar -xzvf ${BACKUP_PATH}/$FILE ./sb_psets/active/*

		EMPTY=`ls -la ./sb_psets/active| wc -l`
		if [ $EMPTY -ne 3 ]; then

			APSETSLIST=`ls ./sb_psets/active`

			if [ "X$DPSETS_PATH" != "X" ]; then
				for i in ${APSETSLIST}
				do
					if [ -d $DPSETS_PATH/$i  ]; then
					  rm -rf $DPSETS_PATH/$i
					fi	
				done
			fi

			cp -p -R ${BACKUP_PATH}/sb_psets/active/* ${APSETS_PATH}
		fi
		rm -rf ${BACKUP_PATH}/sb_psets
	fi

	DPSETS_EXIST=`tar -ztf ${BACKUP_PATH}/$FILE | grep ./sb_psets/dactive/`
	if [ "X$DPSETS_EXIST" != "X" ]; then
		cd ${BACKUP_PATH}
		if [ -z $APSETS_PATH ]; then
			echo Enter full path to active Sitebuilder Page Sets:
			read APSETS_PATH
		fi
		if [ -z $DPSETS_PATH ]; then
			echo Enter full path to non-active Sitebuilder Page Sets:
			read DPSETS_PATH
		fi
			
		mkdir -p ${DPSETS_PATH}
		tar -xzvf ${BACKUP_PATH}/$FILE ./sb_psets/dactive/*

		EMPTY=`ls -la ./sb_psets/dactive| wc -l`
		if [ $EMPTY -ne 3 ]; then

			DPSETSLIST=`ls ./sb_psets/dactive`

			if [ "X$APSETS_PATH" != "X" ]; then
				for i in ${DPSETSLIST}
				do
					if [ -d $APSETS_PATH/$i  ]; then
					  rm -rf $APSETS_PATH/$i
					fi	
				done
			fi
		
			cp -p -R ${BACKUP_PATH}/sb_psets/dactive/* ${DPSETS_PATH}
		fi
		rm -rf ${BACKUP_PATH}/sb_psets
	fi

	#restore SB modules config
	MODULES_EXIST=`tar -ztf ${BACKUP_PATH}/$FILE | grep ./sb_modules/`
	if [ "X$MODULES_EXIST" != "X" ]; then
		cd ${BACKUP_PATH}
		if [ -z $PATH_TO_MODULES ]; then
			echo Enter full path to Sitebuilder modules:
			read PATH_TO_MODULES
		fi
			
		mkdir -p ${PATH_TO_MODULES}
		tar -xzvf ${BACKUP_PATH}/$FILE ./sb_modules/*
		cp -p -R ${BACKUP_PATH}/sb_modules/* ${PATH_TO_MODULES}
		rm -rf ${BACKUP_PATH}/sb_modules
	fi

fi

rm -rf ${BACKUP_PATH}/cache

cd $old_path